;****************************************************
;			DS1307 specific Equates
;****************************************************
.equ DS1307_Write_ADDRESS 	= 0xD0	;Write Adress of DS1307 Real Time Clock
.equ DS1307_Read_ADDRESS 	= 0xD1	;Read Adress of DS1307 Real Time Clock

.equ SQWE 				= 0x10	;Square Wave Enable
.equ Hz_1  				= 0x00	;1 Hz Output at Pin SQW/OUT
.equ CH					= 0x80	;Stop Clock
.equ Seconds_Register	= 0x00 
.equ Minutes_Register	= 0x01
.equ Hours_Register		= 0x02
.equ Day_Register		= 0x03
.equ Date_Register		= 0x04
.equ Month_Register		= 0x05
.equ Year_Register		= 0x06
.equ Control_Register	= 0x07
.equ RAM_Start 			= 0x08
.equ RAM_End 			= 0x3F

DS1307_Init:
;*******************************************************
;******     MUST be done first when :
;****** 1.) a brandnew Chip is used,otherwise DS1307-Clock will not start,or
;****** 2.) Backup-Battery was removed/replaced or
;****** 3.) no Backup-Battery is used at all (make this sense ??)
;
; Predefined Date/Time-Values (_Seconds->_Year) will be stored
; in DS1307 Timekeeper-Registers.
;*******************************************************
	ldi TO_I2C,DS1307_Write_ADDRESS
	rcall I2C_Start				;Start,Address -> DS1307
	ldi TO_I2C,Seconds_Register	;select "second"-Register
	rcall I2C_PutByte
	ldi TO_I2C,_Seconds			;write seconds and clear CH-Bit (start clock)
	rcall I2C_PutByte
	ldi TO_I2C,_Minutes			;write to "Minutes"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,_Hours			;write to "Hours"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,_Day				;write to "Day"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,_Date			;write to "Date"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,_Month			;write to "Month"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,_Year			;write to "Year"-Register	
	rcall I2C_PutByte
	ldi TO_I2C,SQWE				;enable 1 Hz Output on Pin SQW/OUT
	rcall I2C_PutByte
	rjmp I2C_Stop				;"ret" is in I2C_Stop

;----------------------------------------------------------
; Reads DS1307-Registers from "Seconds" up to "Month" and
; store the contents in SRAM pointet to by ZL:ZH.After each
; byte read "ACK" will be sent to DS1307.
; After read of the last  Register ("Year") the content
; of "Year" is also stored in SRAM but "NACK" and "STOP" will
; be sent to DS1307 to indicate the end of read-process.
;----------------------------------------------------------- 

Read_Registers:					;and store it in SRAM
	ldi Work,6					;read first 6 Registers (Seconds->Month)
	ldi ZL,low(seconds)			;set pointer to SRAM-Location "seconds"
	ldi ZH,high(seconds)
	ldi TO_I2C,DS1307_Write_ADDRESS
	rcall I2C_Start
	ldi TO_I2C,Seconds_Register	;set Register-Pointer to "seconds" Timekeeper-Address
	rcall I2C_PutByte
;now read Data pointed to by Register-Pointer
	ldi TO_I2C,DS1307_Read_ADDRESS
	rcall I2C_Start				;Start,Address -> DS1307
Read_Loop:
	rcall I2C_GetByte			;read Data to Register From_I2C
	st Z+,From_I2C
	dec Work					;Register "Month" read?
	brne Read_Loop				;no,loop again
	set							;set Flag "Last byte to receive"

;---- The last Byte read MUST be terminated by a "NACK" --------------------
;---- otherwise the DS1307 will not work correctly !!   --------------------

	rcall I2C_GetByte			;now read last (Year) Register,then send "NACK" and "STOP"
	st Z+,From_I2C
	clt							;clear "last byte" flag
	rjmp I2C_Stop				;"ret" is in I2C_Stop
;-----------------------------------------
;all Time/Date Values from DS1307 are stored
;now in SRAM for further operations
;-----------------------------------------
